Welcome to Choppy
=================

.. image:: _static/choppy-logo.png
    :alt: Choppy: reproducible omics pipeline
    :align: right
    :target: http://docs.3steps.cn

Welcome to Choppy's documentation. Get started with :ref:`installation`
and then get an overview with the :ref:`quickstart`. There is also a
more detailed `tutorial`_ that shows how to analyze omics data
with Choppy. The rest of the docs describe each component of
Choppy in detail, with a full reference in the :ref:`api` section.

Choppy depends on the `Cromwell`_ Workflow Management System and the
`WDL`_ Workflow Definition Language. The documentation for these libraries
can be found at:

- `Cromwell documentation <https://cromwell.readthedocs.io/en/stable/>`_
- `WDL documentation <https://software.broadinstitute.org/wdl/documentation/spec>`_

.. _tutorial: http://docs.3steps.cn/docs/choppy-intro.html
.. _Cromwell: https://cromwell.readthedocs.io/en/stable/
.. _WDL: https://software.broadinstitute.org/wdl/documentation/spec

.. include:: contents.rst.inc
